---
date: "2023-11-07"
title: "0.34 Upgrade Guide"
description: "An upgrade guide that addresses breaking changes in 0.34.0"
authors: ["dsmith3197"]
release: "0.34.0"
hide_on_release_notes: false
badges:
  type: breaking change
---

Vector's 0.34.0 release includes **breaking changes**:

1. [Removal of Deprecated Datadog Component Config Options](#datadog-deprecated-config-options)
1. [Removal of Deprecated `component_name` Metric Tag](#deprecated-component-name)
1. [Removal of Deprecated Metrics Replaced by `component_errors_total`](#deprecated-component-errors-total-metrics)
1. [Removal of `peer_addr` Metric Tag](#remove-peer-addr)
1. [Blackhole sink no longer reports by default](#blackhole-sink-reporting)
1. [Remove direct OpenSSL legacy provider support](#openssl-legacy-provider)
1. [Removal of the deprecated `armv7` rpm package](#armv7-rename)
1. [Default config location change](#default-config-location-change)

and **deprecations**:

1. [Deprecation of `requests_completed_total`, `request_duration_seconds`, and `requests_received_total` Internal Metrics](#deprecate-obsolete-http-metrics)
1. [Deprecation of `repositories.timber.io` package repositories](#timber-package-deprecation)

We cover them below to help you upgrade quickly:

## Upgrade guide

### Breaking changes

#### Removal of Deprecated Datadog Component Config Options {#datadog-deprecated-config-options}

The `region` config option has been removed from the Datadog Events, Logs, and Metrics sinks.
Instead the `site` option should be used.

The `region` and `application_key` config options have been removed from the Enterprise
configuration. Instead of `region`, `site` should be used. `application_key` is no longer required.

#### Removal of Deprecated `component_name` Metric Tag {#deprecated-component-name}

The deprecated `component_name` tag has been removed from all internal metrics. Instead, the
`component_id` tag should be used.

#### Removal of Deprecated Metrics Replaced by `component_errors_total` {#deprecated-component-errors-total-metrics}

The following deprecated internal metrics have been removed. The `component_errors_total` metric
should be used instead.

| Metric Name                                      | Components                                                                    |
|--------------------------------------------------|-------------------------------------------------------------------------------|
| parse_errors_total                               | apache metrics, dnstap, eventstoredb, http server, mongodb, nginx, prometheus |
| http_request_errors_total                        | apache metrics, aws ecs metrics, eventstoredb, http client, nginx, splunk hec |
| http_error_response_total                        | aws ecs metrics, http client                                                  |
| request_read_errors_total                        | aws kinesis firehose, heroku logplex                                          |
| request_automatic_decode_errors_total            | aws kinesis firehose                                                          |
| sqs_message_processing_failed_total              | aws sqs                                                                       |
| sqs_message_delete_failed_total                  | aws sqs                                                                       |
| sqs_message_delete_batch_failed_total            | aws sqs                                                                       |
| sqs_message_receive_failed_total                 | aws sqs                                                                       |
| sqs_message_delete_failed_total                  | aws sqs                                                                       |
| decoder_framing_errors_total                     | codecs                                                                        |
| decoder_deserialize_errors_total                 | codecs                                                                        |
| encoder_framing_errors_total                     | codecs                                                                        |
| encoder_serialize_errors_total                   | codecs                                                                        |
| communication_errors_total                       | docker                                                                        |
| timestamp_parse_errors_total                     | docker                                                                        |
| logging_driver_errors_total                      | docker                                                                        |
| fingerprint_read_errors_total                    | file                                                                          |
| file_delete_errors_total                         | file                                                                          |
| file_watch_errors_total                          | file                                                                          |
| checkpoint_write_errors_total                    | file                                                                          |
| glob_errors_total                                | file                                                                          |
| decode_errors_total                              | file                                                                          |
| http_bad_requests_total                          | http server                                                                   |
| invalid_record_total                             | journald                                                                      |
| invalid_record_bytes_total                       | journald                                                                      |
| consumer_offset_updates_failed_total             | kafka                                                                         |
| kafka_header_extraction_failures_total           | kafka                                                                         |
| k8s_event_annotation_failures_total              | k8s                                                                           |
| requests_received_total                          | heroku logplex                                                                |
| request_errors_total                             | mongodb, postgresql                                                           |
| reload_errors_total                              | reload                                                                        |
| config_load_errors_total                         | reload                                                                        |
| recover_errors_total                             | reload                                                                        |
| encode_errors_total                              | sematext                                                                      |
| connection_errors_total                          | socket, tcp, unix                                                             |
| connection_failed_total                          | tcp, udp, unix                                                                |
| connection_send_ack_errors_total                 | tcp                                                                           |
| windows_service_does_not_exist_total             | windows                                                                       |

#### Removal of `peer_addr` Metric Tag {#remove-peer-addr}

The `peer_addr` tag has been removed from the `component_received_bytes_total` internal metric for TCP-based sources due to its unbounded cardinality.

#### Blackhole sink no longer reports by default {#blackhole-sink-reporting}

The `blackhole` sink no longer reports events processed every second by default. Instead this
behavior can be opted into by setting `print_interval_secs` to `1` (or any other integer). This
change was made due to users being surprised that this sink generates output by default.

#### Remove direct OpenSSL legacy provider support {#openssl-legacy-provider}

In this release, we drop support for enabling the OpenSSL legacy provider via
`--openssl-legacy-provider` (and its environment variable: `VECTOR_OPENSSL_LEGACY_PROVIDER`). This
flag was deprecated in v0.33.0.

The legacy OpenSSL provider (and other providers than the default provider) can still be enabled if
desired through [options in OpenSSL's configuration](/docs/reference/configuration/tls)

#### Removal of the deprecated `armv7` rpm package {#armv7-rename}

The deprecated name of the `armv7` RPM package, `vector-<version>-1.armv7.rpm`, is no longer
published. Instead, it is published as `vector-<version>-1.armv7hl.rpm` to better follow RPM
guidelines. If you are using `yum` to install the RPM, this change should be transparent.

#### Default config location change {#default-config-location-change}

The default config location is now `/etc/vector/vector.yaml` rather than `/etc/vector/vector.toml`.
This is part of the migration to YAML as Vector's preferred configuration language (though TOML and
JSON will still be supported for the forseeable future). If you need Vector to load
`/etc/vector/vector.toml` you must now specify `--config /etc/vector/vector.toml` or
`VECTOR_CONFIG=/etc/vector/vector.toml`

See the associated [release highlight from v0.33.0](/highlights/2023-08-30-yaml-default-format) for
more details on the motivation for migrating from TOML to YAML as the default configuration
language.

### Deprecations

#### Deprecation of `requests_completed_total`, `request_duration_seconds`, and `requests_received_total` Internal Metrics {#deprecate-obsolete-http-metrics}

The `requests_completed_total`, `request_duration_seconds`, and `requests_received_total` internal metrics are removed in the 0.35.0 release.

| Deprecated metric           | Replacement metric                  | Affected components                                                                      |
|-----------------------------|-------------------------------------|------------------------------------------------------------------------------------------|
| requests_completed_total    | http_client_responses_total         | apache metrics, aws ecs metrics, http client, prometheus remote write, prometheus scrape |
| request_duration_seconds    | http_client_response_rtt_seconds    | apache metrics, aws ecs metrics, http client, prometheus remote write, prometheus scrape |
| requests_received_total     | http_server_requests_received_total | aws kinesis firehose, heroku logplex, prometheus exporter, splunk hec                    |

#### Deprecation of `repositories.timber.io` package repositories {#timber-package-deprecation}

Starting with the `v0.34.0` release, we are starting our migration of OS package hosting from
`repositories.timber.io` to `apt.vector.dev` and `yum.vector.dev`. This is the last point release
that will be published to `repositories.timber.io` (any `v0.34.x` patch releases will still be
published). The repositories at `repositories.timber.io` will be decommissioned on February 28th,
2024. Please see the [release highlight](/highlights/2023-11-07-new-linux-repos) for details about
this change and instructions on how to migrate.
